#
# spec file for package xrootd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with    ceph

%if 0%{?sle_version} < 150000 && !0%{?is_opensuse}
%bcond_with    libc_semaphore
%else
%bcond_without libc_semaphore
%endif

%define __builder ninja

Name:           xrootd
Version:        4.12.8
Release:        bp154.1.181
%define plugver 4
Summary:        An eXtended Root Daemon
License:        LGPL-3.0-or-later
Group:          System/Daemons
URL:            http://xrootd.org/
Source0:        https://github.com/xrootd/xrootd/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source100:      xrootd-rpmlintrc
BuildRequires:  cmake >= 2.8
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  graphviz-gd
BuildRequires:  graphviz-gnome
BuildRequires:  ncurses-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  readline-devel
BuildRequires:  swig
BuildRequires:  systemd
BuildRequires:  systemd-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)
%if %{with libc_semaphore}
BuildRequires:  glibc-devel >= 2.21
%else
BuildRequires:  glibc-devel
%endif
%if %{with ceph}
BuildRequires:  librados-devel
BuildRequires:  libradosstriper-devel
%endif
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(libtirpc)
%endif

%description
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones. It is
based on a scalable architecture, a communication protocol, and
a set of plugins and tools based on those. The ability to
configure it and to make it scale (for size and performance)
allows the deployment of data access clusters of virtually any
size, which can include sophisticated features, like
authentication/authorization, integrations with other systems,
WAN data distribution, etc.

The XRootD software framework is a generic suite for data access,
which can serve natively any kind of data, organized as a
hierarchical filesystem-like namespace, based on the concept
of a directory.

%package        ceph
Summary:        Ceph back-end plug-in for XRootD
Group:          System/Filesystems
Requires:       %{name}-server = %{version}

%description    ceph
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains Ceph storage back-end plug-in for the
XRootD server.

%package        ceph-devel
Summary:        Ceph back-end plug-in for XRootD
Group:          Development/Libraries/C and C++
Requires:       %{name}-ceph = %{version}
Requires:       %{name}-server = %{version}

%description    ceph-devel
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains header files and development libraries
for XRootD Ceph storage back-end plug-in development.

%package        client
Summary:        XRootD command line client tools
Group:          Productivity/Clustering/Computing
Requires:       %{name}-client-libs = %{version}
Requires:       %{name}-libs = %{version}
Provides:       %{name}-cl = %{version}
Obsoletes:      %{name}-cl < %{version}

%description    client
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains the command line tools used to
communicate with XRootD servers.

%package        client-libs
Summary:        Libraries used by XRootD clients
Group:          System/Libraries
Requires:       %{name}-libs = %{version}

%description    client-libs
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains libraries used by XRootD clients.

%package        client-devel
Summary:        Development files for XRootD clients
Group:          Development/Libraries/C and C++
Requires:       %{name}-client-libs = %{version}
Requires:       %{name}-libs-devel = %{version}
Provides:       %{name}-cl-devel = %{version}
Obsoletes:      %{name}-cl-devel < %{version}
Recommends:     %{name}-client = %{version}

%description    client-devel
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains header files and development libraries
for XRootD client development

%package        doc
Summary:        Developer documentation for the XRootD libraries
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains the API documentation of the XRootD
libraries.

%package        fuse
Summary:        FUSE-based XRootD filesystem mount
Group:          System/Filesystems
Requires:       %{name}-client = %{version}
Requires:       %{name}-libs = %{version}
Requires:       fuse

%description    fuse
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains the FUSE (file system in user space)
XRootD mount tool.

%package        libs
Summary:        XRootD core libraries
Group:          System/Libraries
%if %{with libc_semaphore}
Requires:       glibc >= 2.21
%endif

%description    libs
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains libraries used by the XRootD servers and
clients.

%package        libs-devel
Summary:        Development files for XRootD core libraries
Group:          Development/Libraries/C and C++
Requires:       %{name}-libs = %{version}

%description    libs-devel
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains header files and development libraries
for XRootD development.

%package        private-devel
Summary:        Private XRootD development files
Group:          Development/Libraries/C and C++
Requires:       %{name}-libs = %{version}

%description    private-devel
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains some private XRootD headers and development
libraries. The use of these fikles is strongly discouraged.
Backwards compatibility between versions is not guaranteed for
them.

%package        server
Summary:        XRootD (eXtended Root Daemon) server
Group:          System/Daemons
Requires:       %{name}-client-libs = %{version}
Requires:       %{name}-libs = %{version}
Requires:       %{name}-server-libs = %{version}
Recommends:     logrotate

%description    server
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

The XRootD (eXtended Root Daemon) server binaries.

%package        server-libs
Summary:        Libraries used by XRootD servers
Group:          System/Daemons
Requires:       %{name}-client-libs = %{version}
Requires:       %{name}-libs = %{version}
Requires:       logrotate
Requires:       systemd
Requires(pre):  systemd
Requires(preun):systemd
Requires(post): systemd
Requires(postun):systemd

%description    server-libs
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains libraries used by XRootD servers.

%package        server-devel
Summary:        Development files for XRootD servers
Group:          Development/Libraries/C and C++
Requires:       %{name}-client-devel = %{version}
Requires:       %{name}-libs-devel = %{version}
Requires:       %{name}-server-libs = %{version}
Recommends:     %{name}-server = %{version}

%description    server-devel
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package contains header files and development libraries
for XRootD server development.

%package     -n python3-%{name}
Summary:        Python 3 bindings for XRootD
Group:          Development/Libraries/Python
Requires:       %{name}-client-libs = %{version}

%description -n python3-xrootd
The XROOTD project gives access to data repositories.
The typical usage is to give access to file-based ones.

This package provides the python 3 bindings for XRootD.

%prep
%autosetup -p1

%build
%cmake \
   -DBUILD_PYTHON:BOOL=ON \
   -DPYTHON_EXECUTABLE:PATH=`which python3` \
   -DPYTHON_LIBRARY:PATH=%{_libdir} \
   -DPYTHON_INCLUDE_DIR:PATH=`python3 -c "from sysconfig import get_path;print(get_path('include'))"` \
   -DENABLE_CEPH:BOOL=%{with ceph} \
   -DUSE_LIBC_SEMAPHORE:BOOL=%{with libc_semaphore}

%cmake_build

cd ..
doxygen Doxyfile

%install
%cmake_install
rm -rf %{buildroot}%{_sysconfdir}/%{name}/*

mkdir -p %{buildroot}%{_var}/log/%{name}
mkdir -p %{buildroot}%{_var}/spool/%{name}

install -Dm 0644 -t %{buildroot}%{_sysconfdir}/%{name}/ packaging/common/*.cfg
install -Dm 0644 -t %{buildroot}%{_unitdir} packaging/common/{cmsd,frm_purged,frm_xfrd,xrootd}@.service
install -Dm 0644 -t %{buildroot}%{_unitdir} packaging/common/{xrdhttp,xrootd}@.socket
install -Dm 0644 packaging/rhel/xrootd.tmpfiles %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -Dm 0644 packaging/common/client.conf %{buildroot}%{_sysconfdir}/%{name}/client.conf
install -p -Dm 0644 packaging/common/xrootd.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/xrootd
install -Dm 0644 packaging/common/client-plugin.conf.example %{buildroot}%{_sysconfdir}/xrootd/client.plugins.d/client-plugin.conf.example

install -Dm 644 README %{buildroot}%{_docdir}/%{name}/README
cp -pr doxydoc/html %{buildroot}%{_docdir}/%{name}/

chmod -x %{buildroot}%{_datadir}/%{name}/utils/XrdCmsNotify.pm

sed -i 's|/usr/bin/env bash|%{_bindir}/bash|' %{buildroot}%{_bindir}/xrootd-config
sed -i 's|/usr/bin/env perl|%{_bindir}/perl|' %{buildroot}%{_datadir}/%{name}/utils/XrdOlbMonPerf
sed -i 's|/usr/bin/env perl|%{_bindir}/perl|' %{buildroot}%{_datadir}/%{name}/utils/netchk

%fdupes %{buildroot}%{_prefix}

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%post client-libs -p /sbin/ldconfig
%postun client-libs -p /sbin/ldconfig

%post server-libs -p /sbin/ldconfig
%postun server-libs -p /sbin/ldconfig

%if %{with ceph}
%post ceph -p /sbin/ldconfig
%postun ceph -p /sbin/ldconfig
%endif

%pre server
getent group xrootd >/dev/null || groupadd -r xrootd
getent passwd xrootd >/dev/null || \
       useradd -r -g xrootd -c "XRootD runtime user" \
       -s /sbin/nologin -d %{_localstatedir}/spool/xrootd xrootd
%service_add_pre cmsd@.service frm_purged@.service frm_xfrd@.service xrootd@.service xrdhttp@.socket xrootd@.socket

%post server
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf
%service_add_post cmsd@.service frm_purged@.service frm_xfrd@.service xrootd@.service xrdhttp@.socket xrootd@.socket

%preun server
%service_del_preun cmsd@.service frm_purged@.service frm_xfrd@.service xrootd@.service xrdhttp@.socket xrootd@.socket

%postun server
%service_del_postun cmsd@.service frm_purged@.service frm_xfrd@.service xrootd@.service xrdhttp@.socket xrootd@.socket

%files client
%license COPYING.LGPL LICENSE
%{_bindir}/xprep
%{_bindir}/xrd
%{_bindir}/xrdadler32
%{_bindir}/xrdcopy
%{_bindir}/xrdcp
%{_bindir}/xrdcp-old
%{_bindir}/xrdfs
%{_bindir}/xrdgsiproxy
%{_bindir}/xrdstagetool
%{_mandir}/man1/xprep.1%{?ext_man}
%{_mandir}/man1/xrd.1%{?ext_man}
%{_mandir}/man1/xrdadler32.1%{?ext_man}
%{_mandir}/man1/xrdcopy.1%{?ext_man}
%{_mandir}/man1/xrdcp.1%{?ext_man}
%{_mandir}/man1/xrdcp-old.1%{?ext_man}
%{_mandir}/man1/xrdfs.1%{?ext_man}
%{_mandir}/man1/xrdgsiproxy.1%{?ext_man}
%{_mandir}/man1/xrdstagetool.1%{?ext_man}

%files client-libs
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdCl.so.*
%{_libdir}/libXrdClient.so.*
%{_libdir}/libXrdFfs.so.*
%{_libdir}/libXrdPosix.so.*
%{_libdir}/libXrdPosixPreload.so.*
# This lib may be used for LD_PRELOAD so the .so link needs to be included
%{_libdir}/libXrdPosixPreload.so
%dir %{_sysconfdir}/%{name}/
%dir %{_sysconfdir}/%{name}/client.plugins.d/
%config %{_sysconfdir}/%{name}/client.plugins.d/client-plugin.conf.example
%config(noreplace) %{_sysconfdir}/%{name}/client.conf

%files client-devel
%license COPYING.LGPL LICENSE
%{_bindir}/xrdgsitest
%{_mandir}/man1/xrdgsitest.1%{?ext_man}
%{_libdir}/libXrdCl.so
%{_libdir}/libXrdClient*.so
%{_libdir}/libXrdFfs.so
%{_libdir}/libXrdPosix.so
%dir %{_includedir}/%{name}/
%{_includedir}/%{name}/XrdCl/
%{_includedir}/%{name}/XrdClient/
%{_includedir}/%{name}/XrdPosix/

%files doc
%license COPYING.LGPL LICENSE
%{_docdir}/%{name}/

%files fuse
%license COPYING.LGPL LICENSE
%{_bindir}/xrootdfs
%{_mandir}/man1/xrootdfs.1%{?ext_man}

%files libs
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdAppUtils.so.*
%{_libdir}/libXrdCrypto.so.*
%{_libdir}/libXrdCryptoLite.so.*
%{_libdir}/libXrdHttpUtils.so.*
%{_libdir}/libXrdUtils.so.*
%{_libdir}/libXrdXml.so.*
%{_libdir}/libXrdClProxyPlugin-%{plugver}.so
%{_libdir}/libXrdSec*-%{plugver}.so
%{_libdir}/libXrdCksCalczcrc32-%{plugver}.so
%{_libdir}/libXrdCryptossl-%{plugver}.so
%{_libdir}/libXrdCmsRedirectLocal-%{plugver}.so

%files libs-devel
%license COPYING.LGPL LICENSE
%{_bindir}/xrootd-config
%{_libdir}/libXrdAppUtils.so
%{_libdir}/libXrdCrypto.so
%{_libdir}/libXrdCryptoLite.so
%{_libdir}/libXrdHttpUtils.so
%{_libdir}/libXrdUtils.so
%{_libdir}/libXrdXml.so
%dir %{_includedir}/%{name}/
%{_includedir}/%{name}/XrdVersion.hh
%{_includedir}/%{name}/XProtocol/
%{_includedir}/%{name}/Xrd/
%{_includedir}/%{name}/XrdCks/
%{_includedir}/%{name}/XrdNet/
%{_includedir}/%{name}/XrdOuc/
%{_includedir}/%{name}/XrdOfs/
%{_includedir}/%{name}/XrdSec/
%{_includedir}/%{name}/XrdSys/
%{_includedir}/%{name}/XrdXml/

%files private-devel
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdSsiLib.so
%{_libdir}/libXrdSsiShMap.so
%dir %{_includedir}/%{name}/
%{_includedir}/%{name}/private/

%files server
%license COPYING.LGPL LICENSE
%{_bindir}/cconfig
%{_bindir}/cmsd
%{_bindir}/frm_admin
%{_bindir}/frm_purged
%{_bindir}/frm_xfragent
%{_bindir}/frm_xfrd
%{_bindir}/mpxstats
%{_bindir}/wait41
%{_bindir}/xrdacctest
%{_bindir}/xrdmapc
%{_bindir}/xrdpfc_print
%{_bindir}/xrdpwdadmin
%{_bindir}/xrdsssadmin
%{_bindir}/xrootd
%{_mandir}/man8/cmsd.8*
%{_mandir}/man8/frm_admin.8*
%{_mandir}/man8/frm_purged.8*
%{_mandir}/man8/frm_xfragent.8*
%{_mandir}/man8/frm_xfrd.8*
%{_mandir}/man8/mpxstats.8*
%{_mandir}/man8/xrdpfc_print.8*
%{_mandir}/man8/xrdpwdadmin.8*
%{_mandir}/man8/xrdsssadmin.8*
%{_mandir}/man8/xrootd.8*
%{_mandir}/man1/xrdmapc.1*
%{_datadir}/%{name}/
%{_unitdir}/cmsd@.service
%{_unitdir}/frm_purged@.service
%{_unitdir}/frm_xfrd@.service
%{_unitdir}/xrootd@.service
%{_unitdir}/xrdhttp@.socket
%{_unitdir}/xrootd@.socket
%{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{_sysconfdir}/%{name}/
%attr(-,xrootd,xrootd) %config(noreplace) %{_sysconfdir}/%{name}/xrootd-clustered.cfg
%attr(-,xrootd,xrootd) %config(noreplace) %{_sysconfdir}/%{name}/xrootd-standalone.cfg
%attr(-,xrootd,xrootd) %config(noreplace) %{_sysconfdir}/%{name}/xrootd-filecache-clustered.cfg
%attr(-,xrootd,xrootd) %config(noreplace) %{_sysconfdir}/%{name}/xrootd-filecache-standalone.cfg
%attr(-,xrootd,xrootd) %config(noreplace) %{_sysconfdir}/%{name}/xrootd-http.cfg
%attr(-,xrootd,xrootd) %dir %{_var}/log/%{name}
%attr(-,xrootd,xrootd) %dir %{_var}/spool/%{name}
# %%ghost %%dir %%{_var}/run/%%{name}

%files server-libs
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdServer.so.*
%{_libdir}/libXrdSsiLib.so.*
%{_libdir}/libXrdSsiShMap.so.*
%{_libdir}/libXrdBlacklistDecision-%{plugver}.so
%{_libdir}/libXrdBwm-%{plugver}.so
%{_libdir}/libXrdFileCache-%{plugver}.so
%{_libdir}/libXrdHttp-%{plugver}.so
%{_libdir}/libXrdN2No2p-%{plugver}.so
%{_libdir}/libXrdOssSIgpfsT-%{plugver}.so
%{_libdir}/libXrdPss-%{plugver}.so
%{_libdir}/libXrdSsi-%{plugver}.so
%{_libdir}/libXrdSsiLog-%{plugver}.so
%{_libdir}/libXrdThrottle-%{plugver}.so
%{_libdir}/libXrdXrootd-%{plugver}.so

%files server-devel
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdServer.so
%dir %{_includedir}/%{name}/
%{_includedir}/%{name}/XrdAcc/
%{_includedir}/%{name}/XrdCms/
%{_includedir}/%{name}/XrdFileCache/
%{_includedir}/%{name}/XrdHttp/
%{_includedir}/%{name}/XrdOss/
%{_includedir}/%{name}/XrdSfs/
%{_includedir}/%{name}/XrdXrootd/

%files -n python3-%{name}
%license COPYING.LGPL LICENSE
%{python3_sitearch}/XRootD/
%{python3_sitearch}/pyxrootd/
%{python3_sitearch}/xrootd-v%{version}-*.egg-info

%if %{with ceph}
%files ceph
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdCeph-%{plugver}.so
%{_libdir}/libXrdCephXattr-%{plugver}.so
%{_libdir}/libXrdCephPosix.so.*

%files ceph-devel
%license COPYING.LGPL LICENSE
%{_libdir}/libXrdCephPosix.so
%endif

%changelog
* Fri Jul  2 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.12.8:
  * [XrdTpc] Buffer starting at the right offset.
  * [XrdHttp] Store a new header in the headers map before
    mangling it, fixes gh#xrootd/xrootd#1399.
  * [XrdHttp] Fix chunked transfer with 100-continue.
- Drop xrootd-build-with-glibc2.33.patch: integrated upstream.
* Mon Feb 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.12.7:
  * [XrdHttp] Fix empty PUT.
  * [XrdTpc] Do not call Write() on flush.
  * [XrdTpc] Avoid using invalid object in multi-stream.
  * [XrdTpc] Always check and fail on error.
  * [XrdTpc] Catch all negative return values not just SFS_ERROR.
  * [XrdTpc] Fix the return value of `Stream::Write`
  * [XrdTpc] Always populate error buffer with messages.
  * [XrdTpc] Factor out recursive writes.
  * [XrdTpc] Do not allow partial buffer writes.
  * [XrdTpc] Adjust buffer size based on number of streams.
- Add xrootd-build-with-glibc2.33.patch: Fix build with glibc
  2.33; patch taken from upstream commit [gh#xrootd/xrootd#1315].
* Thu May 28 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.12.1:
  * [XrdXrootdVoms] Fix run-time lib dependencies.
  * [xrdcp] Don't create unwanted dir if --recursive option was
    used and the source is a file.
- Changes from version 4.12.0:
  * New Features:
  - [Server] User redirector to find directory to be listed (R5
    backport).
  - [XrdCl] More effective error recovery policy when the source
    is a metalink.
  - [xrdcp] Implement bandwidth limiting (--xrate option).
  - [xrdcp] Implement ability to continue interrupted transfer
    (--continue).
  - [xrdcp/Python] Add an option (--zip-mtln-cksum) to use the
    checksum from a metalink with files extracted from ZIP
    archives.
  - [xrdcp/Python] Automatically infer checksum type if asked
    to.
  - [xrdcp/Python] Add an option (--rm-bad-cksum) to
    automatically remove destination file if the checksum check
    failed.
  * Bug fixes:
  - [Server] Correct sequencing of an async close to prevent a
    SEGV.
  - [Server] Add missing initializer to avoid TPC SEGV on busy
    systems.
  - [Server] Initialize the XrdAccEntityInfo structure.
  - [XrdHttp] Fix MKCOL response when we have an EEXIST.
  - [XrdHttp] Periodically reload verify cert store.
  - [XrdHttp] Disable session cache.
  - [XrdCl] Don't set on-connection handler for local files.
  - [XrdCl] Don't set the stream error window for auth errors.
  - [XrdCl] Fix race condition resulting in dangling pointer to
    SidMgr.
  - [XrdCl] Make Channel operations thread-safe in respect to
    ForceDisconnect.
  * [CMake] Repleace XRootD find module with config module.
  * [RPM/CMake] Don't build XrdCns.
  * [Packaging] Add xrootd-voms and xrootd-voms-devel packages
    equivalent.
  * [Packaging] Add additional private headers for vomsxrd to the
    vomsxrd packages.
  * [Python] Support PyPy.
- Only package the COPYING.LGPL file and drop all extraneous
  COPYING* files; the LICENSE file makes it clear that the
  software is licensed under LGPL-3.0-or-later.
* Fri Apr  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.11.3:
  * [Server] Avoid SEGV when skipping over large if/else/fi
    blocks.
  * [XrdHttp] Fix curl speed limit to be really around 10KB/s.
  * [xrootdfs] Make sure xrootdfs_create() checks return code of
    xrootdfs_do_create().
  * [XrdHttp] Change the default ssl cipher.
  * [XrdHttp] Enable elliptic-curve support for OpenSSL 1.0.2+.
  * [XrdHttp] Use Mozilla cipher list only with OpenSSL 1.0.2+.
  * [XrdCl] When xrdcp reports an error refine the message so it
    is clear whether the erros comes from the source or
    destination.
  * [XrdCl] Make sure on error local redirect is not retried
    infinitely.
  * [XrdXrootdConfig] Fixed wrong segsz parameter.
  * [XrdHttp] Give a chance to map the issuer name in the case of
    a proxy certificate (needed to accommodate systems that do
    user mapping, e.g. eos)
  * [XrdHttp] Fix the logic for determining SecEntity.name.
  * [XrdHttp] Don't overwrite SecEntity.name after the gridmap
    phase.
  * [xrootdfs] Make sure xrootdfs_create() does check the return
    code of xrootdfs_do_create().
  * [XrdSecgsi] In the case of delegation, give client a chance to
    use XrdSecGSISRVNAMES to limit where it is being redirected
    to.
  * [Python] Make rpath relative to the module.
  * [Debian] Proper Debian pkg naming.
  * [XrdCl] Use glibc semaphores for rhel>=7.
  * [Server] Export pointers to Acc, Ofs, and Sfs plugin into the
    XrdEnv.
  * [XrdMacaroons] Use env ptrs to get authorize obj.
- Changes from versions 4.11.0 through 4.11.2:
  * See
    https://github.com/xrootd/xrootd/blob/v4.11.3/docs/ReleaseNotes.txt.
- Remove a spurious 'exit 0' line from %%pre scriptlet.
- Recommend logrotate for xrootd-server as it installs a file in
  /etc/logrotate.d/.
- Use ninja for building:
  * Add BuildRequires: ninja.
  * Use %%cmake_build instead of make.
  * Define __builder to ninja so cmake uses ninja instead of make
    for building.
* Mon Aug 19 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.10.0:
  * New Features
  - [POSIX] Add methods to the cache mngt objecT to get status
    of a cached file.
  - [Server] Add xrd.network dyndns option for dynamic DNS
    handling.
  - [Server] Properly handle dynamic DNS environments.
  - [Server] Add evict option to the prepare request.
  - [Server] Allow better handling for proxy caching clusters.
  - [Server] Allow configurable posc sync level.
  - [Server] Implement framework for a kXR_prepare plug-in.
  - [XrdCl] Implement streaming dirls, closes #225
  - [XrdCl] Retry policy changes: see details in #950.
  - [XrdCl] Add switch/flag to enforce zip archive listing.
  - [XrdCl] Preserve tried/triedrc cgi info on redirect for
    kXR_locate request, #closes #944
  - [XrdCl] Implement prepare evict and expose in xrdfs.
  - [XrdCl] Expose prepare abort and query prepare.
  - [XrdCl] Add tpc.scgi if delegation is being used.
  - [Python] Expose chunked dirlist API in Python.
  - [Python] Support globbing.
  - [XrdClHttp] Add XrdClHttp submodule.
  - [XCache] Implement write-queue number of blocks / threads
    config options. (#963)
  - [CMake] Add switch for XrdCl builds only.
  * Major bug fixes:
  - [XrdCl] Allow to cancel classical copy jobs.
  - [XrdCl] Fix race condition in error recovery.
  - [XrdCl] Prevent race condition between Request T/O and
    socket read.
  - [XCache] Check for errors during XrdOssFile::FSync - do not
    write cinfo file if it fails.
  - [XCache] Deny write access to a file in initial Prepare()
    call, fixes #663
  - [XCache] Review and correct error handling in POSIX and
    XCache, implement XCache::Unlink()
  - [XrdTpc] Always query dual stack for HTTP TPC.
  - [XrdTpc] Do not include authz header in the filename.
  - [XrdTpc] Add curl handle cleanup on redirections or errors.
  - [XrdHttp] Include provided opaque information in the
    redirection.
  - [XrdHttp] Fix digest names returned to clients.
  - [XrdHttp] Fix opaque info handling on redirections.
  - [XrdMacaroon] Fix macaroon authorization config.
  - [XrdSecgsi] Make proxy cache path aware.
  - [XrdSecgsi] XrdSecProtocolgsi::Encrypt - set IV correctly
    and report correct size.
  * Minor bug fixes and miscellaneous changes: see
    https://github.com/xrootd/xrootd/blob/master/docs/ReleaseNotes.txt
- Use github URL for source tarball.
- Replace xrootd-devel by xroots-libs-devel for
  xrootd-server-devel's Requires; xrootd-devel does not exist.
* Thu Jan 17 2019 Jan Engelhardt <jengelh@inai.de>
- Disable ceph since linking to it fails.
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Trim long repeated descriptions in subpackages.
- Trim future aims. Run fdupes over all of the usr subvolume.
* Wed Dec  5 2018 Todd R <toddrme2178@gmail.com>
- Update to version 4.8.5
- Remove upstream-included xrootd-gcc6-fix.patch
- Remove unneeded xrootd-gcc8-fix.patch
- Merge cl and cl-devel subpackages into client and client-devel
  subpackages, respectively, to match upstream
- Split client and server libraries into subpackages to simplify
  dependencies, simplify installation, and better match upstream.
- Switch to cmake-based install
- Switch from sysv-init to systemd.
- Build and package python3 bindings
- Build and package ceph storage backend
- Build and package documentation
* Sun Jul  1 2018 bugs@vdm-design.de
- Add patch xrootd-gcc8-fix.patch to fix build with gcc8
* Wed Mar  7 2018 bugs@vdm-design.de
- Fix build for factory, rpc/types.h is gone from glibc-devel,
  use the one from tirpc-devel instead
* Fri Dec 22 2017 bugs@vdm-design.de
- Disable crypto for Leap 15 and Tumbleweed to make it build again
  newer openssl versions are not supported by version < 4
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sun Jun 19 2016 bugs@vdm-design.de
- Fix compilation with GCC6 in Tumbleweed, by applying patch
  xrootd-gcc6-fix.patch
  Patch taken from https://sft.its.cern.ch/jira/browse/ROOT-8184
  Fix is included in upstream version 4.3.0. We do not update to
  this version, as other packages that use xrootd do not compile
  against versions >= 4.0
- Fixes bnc#985167
* Wed Jun 25 2014 bugs@vdm-design.de
- Remove %%ghost entry in /var/run to fix rpmlint error
* Sun Jan 26 2014 bugs@vdm-design.de
- Update to version 3.3.6
  * Prevent SEGV when error occurs during stat (issue #70)
  * Prevent SEGV in redirect monitoring (issue #61)
  * Set reasonable linux thread limit and warn it we cannot do so.
  * Support for C++11 (narrowing fixes, unique_ptr vs. auto_ptr)
  * Support for CMake 2.8.12 (interface link libraries)
  * Fix minor Coverity issues in XrdCl
  * Fix a rarely occuring segfault when forking XrdCl under heavy load
  * Fix various issues related to group name retrieval (issues #51, #52, #53)
  * Make XrdSys/XrdSysIOEvents.hh private - could not have been used anyways
  * Add a sysconfig template to preload custom allocators in order to fix
    memory issues on RHEL6
  * Allow up to 63 characters for a site name
* Mon Oct 14 2013 bugs@vdm-design.de
- Update to version 3.3.4
  * Serialize sss authentication client initialization to prevent race
    conditions
  * Actually cancel the JobManager threads while stopping it - this affected
    client side fork handling (new client)
  * Restore original meaning of -adler and -md5 to xrdcp (issue #44)
  * Append CGI info when retrying at a server that handshaked but never
    respnded to the request (xrdcp)
  * Do socket accepts asynchronously to prevent DNS resolution from blocking
    accepts (issue #33)
  * Warn about incomplete dirlist responses (xrdfs)
  * Cast the utilization statistics to uint16_t before printing to
    print actual numbers instead of letters corresponding to ASCII codes
    (xrdfs)
  * When calling File::Stat use file handle instead of path
  * Improve handling of malformed kXR_readv responses (new client)
  * Explain parameters of xrdcopy --tpc (documentation, issue #46)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Sat Apr 27 2013 bugs@vdm-design.de
- Update to version 3.3.2
  * Fix the opaque information setting in xrdcp using -OD (issue #1)
  * Fix compilation on Solaris 11 (issue #7)
  * Fix issues with semaphore locking during thread cancelation on MaxOSX (issue #10)
  * Solve locking problems in the built-in poller (issue #4)
  * Solve performance issues in the new client. Note: this actually changes some low level public interfaces, so the soname of libXrdCl.so has been bumped to libXrdCl.so.1. The xrootd.org RPMs also provide the old libXrdCl.so.0 in order to preserve the binary compatibility with the clients linked against it.
* Thu Mar  7 2013 bugs@vdm-design.de
- update to version 3.3.1
  * Correct XrdClient ABI incompatibility issue introduced in 3.3.0
  * Install additional private headers
* Mon Mar  4 2013 cfarrell@suse.com
- license update: LGPL-3.0+
  See the LICENSE file (prior to September 2012 BSD - now, license is
  LGPL-3.0+)
* Sat Feb 23 2013 bugs@vdm-design.de
- update to version 3.3.0
  * Changelog: http://xrootd.cern.ch/cgi-bin/cgit.cgi/xrootd/tree/docs/ReleaseNotes.txt?id=v3.3.0
* Thu Dec 13 2012 bugs@vdm-design.de
- update to version 3.2.7
  * For OpenSSL versions prior to 1, make the 'default' and 'old' hash
    algorithm result the same. This fixes Savannah bug #98997.
  * Do not rebuild the full chain when the CRL is invalidated; also, make
    sure that the invalid CRL object in only deleted when no longer in use.
    Fixes bug #99074.
  * Allow for null fields in the cgi string.
  * Add missing return statement to avoid SEGV during write error recovery
    under certain circumstances. Fixes bug #99002.
* Fri Nov  9 2012 bugs@vdm-design.de
- update to version 3.2.6
  * GSI authentication: fix possible race condition while re-loading CA
    certificates; fix also related memory leaks.
  * GSI authentication: make sure the CA cache is not initialized twice (e.g.
    server and client inside there), and that the cache entry pointers are
    always initialized.
  * Crypto OpenSSL modules: use more appropriate way to read the RSA complete key,
    solving various issues for RH6 and derivations, included SL(C)6.
  * Make sure redirect opaque information is passed along for all filename
    based requests. This is required for DPM and EOS N2N services to work
    in all cases (most importantly, stat).
  * Make sure buffer ends with null byte before read suspension. This only
    occurs on very heavily loaded connections.
  * Fix the fast response queue so that it doesn't run out of response
    slots causing a big performance penalty. This is a high priority fix.
  * Properly detect external process failure and report correct error status
    to a client.  This also fixes bug report #91141.
  * [XRootDPosix] Make sure to use a supplied cache even when no cache
    directives given.
  * Make sure to return a usable path string via XrdOucCacheIO::Path().
  * Actually support 4 different redirect destinations.
  * Transparent support for new name hashing algorithm adopted in openssl
    1.0.0x (GSI authentication protocol)
  * Verbosity levels revised for GSI and PWD authentication protocols.
  * Notification of initialization option for GSI and PWD authentication
    protocols.
  * Do not repudiate file existence on an "cancelled" error during open.
    this patch addresses overloaded dCache pool nodes.
* Mon Oct  8 2012 bugs@vdm-design.de
- fix licence
- update to version 3.2.5
  * Make realoading gridmapfile atomic (protect from segfault)
  * Propagate to clients proper range of errors during read/write operations
  * Fix segfault when handling writes to files that have not been opened
* Tue Sep 11 2012 bugs@vdm-design.de
- Update to version 3.2.4
  * Work around a dead-lock in the client fork handlers.
* Wed Sep  5 2012 bugs@vdm-design.de
- Update to version 3.2.3
  * Make sure read statistics are updated for sendfile() and mmap I/O.
  * Make sure refresh thread is dead before deleting deleting the keytab to
    avoid SEGV's.
  * Add missing include for compiling with gcc-4.7 (from Sebastien Binet).
    This patch is required for successful compilation.
  * Avoid segfaults when limiting number of redirections caused by failed
    authorization.
  * Avoid deadlock in the client fork handlers.
  * Correct monitor initialization test to start monitor under all configs.
  * Fix a memory leak in the client handshake algorithm.
  * Fuse: Use default TTL values for data server connection and load
    balance server connection.
* Wed Jun 20 2012 bugs@vdm-design.de
- update to version 3.2.2
  * Correct test whether or not to initialize redirect monitoring. The old
    code never initialized it this disabling redirect monitoring.
  * Backport frm notification fix that stalled stage-in requests from commit
    69e38cfd6b8bb024dd34f8eb28a666fbf97f346b
  * Prevent SEGV when xrd.monitor rbuff value not specified
  * Prevent xrdcp hangs when doing exterme copy from server to server.
  * In case of 'limited proxy' look for VOMS attributes also in the parent
    proxy.
  * Correct log processing for sites that use the root directory as the
    stomping ground for newly created files.
* Wed Jun 13 2012 bugs@vdm-design.de
- update to upstream version 3.2.1
* Mon Feb 20 2012 bugs@vdm-design.de
- Add spec file based on the one distributed with the sources
